@@ -47,7 +47,6 @@ class SentenceTransformer(nn.Sequential):
                 model_path = os.path.join(default_cache_path, folder_name)
                 os.makedirs(model_path, exist_ok=True)
 
-
                 if not os.listdir(model_path):
                     if model_url[-1] is "/":
                         model_url = model_url[:-1]
@@ -87,22 +86,29 @@ class SentenceTransformer(nn.Sequential):
         if device is None:
             device = "cuda" if torch.cuda.is_available() else "cpu"
             logging.info("Use pytorch device: {}".format(device))
+
         self.device = torch.device(device)
         self.to(device)
 
-    def encode(self, sentences: List[str], batch_size: int = 8, show_progress_bar: bool = None) -> List[ndarray]:
+    def encode(self, sentences: List[str], batch_size: int = 8, show_progress_bar: bool = None, output_value: str = 'sentence_embedding', convert_to_numpy: bool = True) -> List[ndarray]:
         """
-       Computes sentence embeddings
+        Computes sentence embeddings
 
-       :param sentences:
+        :param sentences:
            the sentences to embed
-       :param batch_size:
+        :param batch_size:
            the batch size used for the computation
-       :param show_progress_bar:
+        :param show_progress_bar:
             Output a progress bar when encode sentences
-       :return:
-           a list with ndarrays of the embeddings for each sentence
-       """
+        :param output_value:
+            Default sentence_embedding, to get sentence embeddings. Can be set to token_embeddings
+            to get wordpiece token embeddings.
+        :param convert_to_numpy:
+            If true, the output is a list of numpy vectors. Else, it is a list of pytorch tensors.
+        :return:
+           Depending on convert_to_numpy, either a list of numpy vectors or a list of pytorch tensors
+        """
+        self.eval()
         if show_progress_bar is None:
             show_progress_bar = (logging.getLogger().getEffectiveLevel()==logging.INFO or logging.getLogger().getEffectiveLevel()==logging.DEBUG)
 
@@ -137,11 +143,22 @@ class SentenceTransformer(nn.Sequential):
                     features[feature_name].append(sentence_features[feature_name])
 
             for feature_name in features:
-                features[feature_name] = torch.tensor(np.asarray(features[feature_name])).to(self.device)
+                #features[feature_name] = torch.tensor(np.asarray(features[feature_name])).to(self.device)
+                features[feature_name] = torch.cat(features[feature_name]).to(self.device)
 
             with torch.no_grad():
-                embeddings = self.forward(features)
-                embeddings = embeddings['sentence_embedding'].to('cpu').numpy()
+                out_features = self.forward(features)
+                embeddings = out_features[output_value]
+
+                if output_value == 'token_embeddings':
+                    #Set token embeddings to 0 for padding tokens
+                    input_mask = out_features['input_mask']
+                    input_mask_expanded = input_mask.unsqueeze(-1).expand(embeddings.size()).float()
+                    embeddings = embeddings * input_mask_expanded
+
+                if convert_to_numpy:
+                    embeddings = embeddings.to('cpu').numpy()
+
                 all_embeddings.extend(embeddings)
 
         reverting_order = np.argsort(length_sorted_idx)
@@ -219,16 +236,20 @@ class SentenceTransformer(nn.Sequential):
         for idx in range(num_texts):
             max_len = max_seq_len[idx]
             feature_lists = {}
+
             for text in paired_texts[idx]:
                 sentence_features = self.get_sentence_features(text, max_len)
 
                 for feature_name in sentence_features:
                     if feature_name not in feature_lists:
                         feature_lists[feature_name] = []
+
                     feature_lists[feature_name].append(sentence_features[feature_name])
 
+
             for feature_name in feature_lists:
-                feature_lists[feature_name] = torch.tensor(np.asarray(feature_lists[feature_name]))
+                #feature_lists[feature_name] = torch.tensor(np.asarray(feature_lists[feature_name]))
+                feature_lists[feature_name] = torch.cat(feature_lists[feature_name])
 
             features.append(feature_lists)
 
@@ -365,7 +386,6 @@ class SentenceTransformer(nn.Sequential):
                     features, labels = batch_to_device(data, self.device)
                     loss_value = loss_model(features, labels)
 
-
                     if fp16:
                         with amp.scale_loss(loss_value, optimizer) as scaled_loss:
                             scaled_loss.backward()
