@@ -1,6 +1,6 @@
-__version__ = "0.2.5.1"
+__version__ = "0.2.6"
 __DOWNLOAD_SERVER__ = 'https://public.ukp.informatik.tu-darmstadt.de/reimers/sentence-transformers/v0.2/'
-from .datasets import SentencesDataset, SentenceLabelDataset
+from .datasets import SentencesDataset, SentenceLabelDataset, ParallelSentencesDataset
 from .data_samplers import LabelSampler
 from .LoggingHandler import LoggingHandler
 from .SentenceTransformer import SentenceTransformer
