@@ -55,9 +55,9 @@ class EmbeddingSimilarityEvaluator(SentenceEvaluator):
 
         if epoch != -1:
             if steps == -1:
-                out_txt = f" after epoch {epoch}:"
+                out_txt = " after epoch {}:".format(epoch)
             else:
-                out_txt = f" in epoch {epoch} after {steps} steps:"
+                out_txt = " in epoch {} after {} steps:".format(epoch, steps)
         else:
             out_txt = ":"
 
