@@ -1,12 +1,18 @@
 from .ALBERT import ALBERT
+from .Transformer import Transformer
 from .BERT import BERT
 from .BoW import BoW
 from .CNN import CNN
+from .CamemBERT import CamemBERT
 from .Dense import Dense
 from .DistilBERT import DistilBERT
 from .LSTM import LSTM
 from .Pooling import Pooling
 from .RoBERTa import RoBERTa
+from .T5 import T5
+from .WKPooling import WKPooling
+from .WeightedLayerPooling import WeightedLayerPooling
 from .WordEmbeddings import WordEmbeddings
 from .WordWeights import WordWeights
+from .XLMRoBERTa import XLMRoBERTa
 from .XLNet import XLNet
